pub fn try_get_message_bus() -> Option<Rc<RefCell<MessageBus>>>Expand description
Returns the thread-local message bus if one has been set for this thread.
pub fn try_get_message_bus() -> Option<Rc<RefCell<MessageBus>>>Returns the thread-local message bus if one has been set for this thread.