pub fn try_publish_any(topic: MStr<Topic>, message: &dyn Any) -> bool
Tries to publish a message to the current thread’s registered message bus.
Returns false when the thread has no bus or the bus is already borrowed.
false